@@ -1,6 +1,7 @@
 from decimal import Decimal, getcontext
 from .safe_math import *
-from .safe_math import exp_it, divide_it  # if you need these
+def exponentials(value,exp=9,num=-1):
+    return multiply_it(value,exp_it(10,exp,num))
 
 # High precision for decimal ops
 getcontext().prec = 50
@@ -8,7 +9,7 @@ getcontext().prec = 50
 # SOL constants
 SOL_DECIMAL_PLACE = 9
 # lamports per SOL = 10**9
-SOL_LAMPORTS = sol_lamports = int(exponential(1, exp=SOL_DECIMAL_PLACE, num=1))
+SOL_LAMPORTS = sol_lamports = int(exponentials(1, exp=SOL_DECIMAL_PLACE, num=1))
 
 
 def get_proper_args(strings, *args, **kwargs):
